@@ -48,11 +48,12 @@ def diffReport(path_file_a, path_file_b, path_file_output='', html_return=True,
     count = 0
     for (i, j) in zip(text_lines_a, text_lines_b):
         a = i
-        b = difflib.get_close_matches(a, text_lines_b, n=1)
-        if b:
-            b = b[0]
-        else:
-            b = ''
+        b = j
+        #b = difflib.get_close_matches(a, text_lines_b, n=1)
+        #if b:
+        #    b = b[0]
+        #else:
+        #    b = ''
         ratio = fuzzyCompare.ratio(a, b)
         ratio_2 = fuzzyCompare.ratio(a, b, partial_ratio)
         if a != b:
